import "#internal/nitro/virtual/polyfill";
import { withQuery } from "ufo";
import { nitroApp } from "../app.mjs";
import {
  normalizeLambdaIncomingHeaders,
  normalizeLambdaOutgoingBody,
  normalizeLambdaOutgoingHeaders
} from "../utils.lambda.mjs";
import { normalizeCookieHeader } from "../utils.mjs";
export async function handler(event, context) {
  const query = {
    ...event.queryStringParameters,
    ...event.multiValueQueryStringParameters
  };
  const url = withQuery(
    event.path || event.rawPath,
    query
  );
  const method = event.httpMethod || event.requestContext?.http?.method || "get";
  if ("cookies" in event && event.cookies) {
    event.headers.cookie = event.cookies.join(";");
  }
  const r = await nitroApp.localCall({
    event,
    url,
    context,
    headers: normalizeLambdaIncomingHeaders(event.headers),
    method,
    query,
    body: event.body
    // TODO: handle event.isBase64Encoded
  });
  if ("cookies" in event || "rawPath" in event) {
    const cookies = normalizeCookieHeader(r.headers["set-cookie"]);
    return {
      cookies,
      statusCode: r.status,
      headers: normalizeLambdaOutgoingHeaders(r.headers, true),
      body: await normalizeLambdaOutgoingBody(r.body, r.headers).then(
        (r2) => r2.body
      )
    };
  }
  return {
    statusCode: r.status,
    headers: normalizeLambdaOutgoingHeaders(r.headers),
    body: await normalizeLambdaOutgoingBody(r.body, r.headers).then(
      (r2) => r2.body
    )
  };
}
